Package: nbpMatching
Type: Package
Title: Functions for Optimal Non-Bipartite Matching
Version: 1.5.6
Date: 2024-09-23
Author: Cole Beck [aut, cre],
  Bo Lu [aut],
  Robert Greevy [aut]
Maintainer: Cole Beck <cole.beck@vumc.org>
Authors@R: c(person("Cole", "Beck", role = c("aut", "cre"),
    email = "cole.beck@vumc.org"),
    person("Bo", "Lu", role = "aut"),
    person("Robert", "Greevy", role = "aut"))
Description: Perform non-bipartite matching and matched randomization. A
    "bipartite" matching utilizes two separate groups, e.g. smokers being
    matched to nonsmokers or cases being matched to controls. A "non-bipartite"
    matching creates mates from one big group, e.g. 100 hospitals being
    randomized for a two-arm cluster randomized trial or 5000 children who
    have been exposed to various levels of secondhand smoke and are being
    paired to form a greater exposure vs. lesser exposure comparison. At the
    core of a non-bipartite matching is a N x N distance matrix for N potential
    mates. The distance between two units expresses a measure of similarity or
    quality as mates (the lower the better). The 'gendistance()' and
    'distancematrix()' functions assist in creating this. The 'nonbimatch()'
    function creates the matching that minimizes the total sum of distances
    between mates; hence, it is referred to as an "optimal" matching. The
    'assign.grp()' function aids in performing a matched randomization. Note
    bipartite matching can be performed using the prevent option in
    'gendistance()'.
License: GPL (>= 2)
Imports: methods, stats, Hmisc, MASS, utils
URL: https://github.com/couthcommander/nbpMatching
Collate: 'distancematrix.R' 'nonbimatch.R' 'assign.grp.R'
        'fill.missing.R' 'gendistance.R' 'make.phantoms.R'
        'nbpmatching-package.R' 'qom.R' 'quantile.R' 'subsetMatches.R'
        'utils.R'
RoxygenNote: 7.3.1
NeedsCompilation: yes
Packaged: 2024-09-24 20:43:47 UTC; beckca
Repository: CRAN
Date/Publication: 2024-09-25 06:50:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-29 14:43:17 UTC; unix
Archs: nbpMatching.so.dSYM
