# Generated by roxygen2: do not edit by hand

exportClasses(distancematrix)
exportClasses(nonbimatch)
exportMethods(assign.grp)
exportMethods(distancematrix)
exportMethods(fill.missing)
exportMethods(full.qom)
exportMethods(gendistance)
exportMethods(get.sets)
exportMethods(make.phantoms)
exportMethods(nonbimatch)
exportMethods(qom)
exportMethods(quantile)
exportMethods(runner)
exportMethods(scalar.dist)
exportMethods(subsetMatches)
import(methods)
import(stats)
importFrom(Hmisc,hdquantile)
importFrom(Hmisc,transcan)
importFrom(MASS,ginv)
importFrom(utils,read.csv)
useDynLib(nbpMatching, .registration = TRUE)
